%define epoch 1

%define client_major 0
%define server_major 0
%define cursor_major 0
%define egl_major    1

%define libname_devel %mklibname %{name} -d

%define client_name %{name}-client
%define client_libname %mklibname %{client_name} %{client_major}

%define server_name %{name}-server
%define server_libname %mklibname %{server_name} %{server_major}

%define cursor_name %{name}-cursor
%define cursor_libname %mklibname %{cursor_name} %{cursor_major}

%define egl_name %{name}-egl
%define egl_libname %mklibname %{egl_name} %{egl_major}

Summary:	Wayland Compositor Infrastructure
Name:		wayland
Version:	1.22.0
Release:	%mkrel 1
License:	MIT
Group:		System/Libraries
Url:		https://wayland.freedesktop.org/
Source0:        https://gitlab.freedesktop.org/%{name}/%{name}/-/releases/%{version}/downloads/%{name}-%{version}.tar.xz

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(libxml-2.0)
# for protocol doc
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	doxygen
BuildRequires:	xmlto
BuildRequires:	graphviz
BuildRequires:	meson

%description
Wayland is a protocol for a compositor to talk to its clients as well
as a C library implementation of that protocol. The compositor can be
a standalone display server running on Linux kernel modesetting and
evdev input devices, an X application, or a wayland client itself. The
clients can be traditional applications, X servers (rootless or
full screen) or other display servers.

%package -n %{libname_devel}
Summary:	Header files for %{name}
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{client_libname} = %{version}-%{release}
Requires:	%{server_libname} = %{version}-%{release}
Requires:	%{cursor_libname} = %{version}-%{release}
Requires:	%{egl_libname} = %{epoch}:%{version}-%{release}
Requires:	%{name}-tools = %{version}-%{release}
Conflicts:	lib64wayland-egl1-devel, libwayland-egl1-devel
Obsoletes:	%mklibname -d wayland-egl1-devel

%description -n %{libname_devel}
This package contains the header and pkg-config files for developing
with %{name}.

%package -n %{client_libname}
Summary:	Libraries for %{client_name}
Group:		System/Libraries

%description -n %{client_libname}
This package contains the libraries for %{client_name}.

%package -n %{server_libname}
Summary:	Libraries for %{server_name}
Group:		System/Libraries

%description -n %{server_libname}
This package contains the libraries for %{server_name}.

%package -n %{cursor_libname}
Summary:	Libraries for %{cursor_name}
Group:		System/Libraries

%description -n %{cursor_libname}
This package contains the libraries for %{cursor_name}.

%package -n	%{egl_libname}
Summary:	Files for Mesa (Wayland EGL libs)
# mesa version was higher than wayland one:
Epoch:		%{epoch}
Group:		System/Libraries
Provides:	lib%{egl_name} = %{version}-%{release}

%description -n	%{egl_libname}
Mesa is an OpenGL %{opengl_ver} compatible 3D graphics library.
Wayland EGL platform parts.

%package tools
Summary:	%{name} devel tools
Group:		System/Libraries
Conflicts:	%{libname_devel} < 0.95-3

%description tools
This package contains development tools for %{name}.

%package doc
Summary:	%{name} documentation
Group:		Documentation
BuildArch:	noarch

%description doc
This package contains documentation of %{name}.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%files -n %{client_libname}
%{_libdir}/lib%{client_name}.so.%{client_major}
%{_libdir}/lib%{client_name}.so.%{client_major}.*

%files -n %{server_libname}
%{_libdir}/lib%{server_name}.so.%{server_major}
%{_libdir}/lib%{server_name}.so.%{server_major}.*

%files -n %{cursor_libname}
%{_libdir}/lib%{cursor_name}.so.%{cursor_major}
%{_libdir}/lib%{cursor_name}.so.%{cursor_major}.*

%files -n %{egl_libname}
%{_libdir}/libwayland-egl.so.%{egl_major}
%{_libdir}/libwayland-egl.so.%{egl_major}.*

%files -n %{libname_devel}
%{_includedir}/%{name}-*.h
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_datadir}/aclocal/%{name}-scanner.m4
%{_datadir}/wayland/wayland-scanner.mk
%{_datadir}/wayland/wayland.xml
%{_datadir}/wayland/wayland.dtd

%files tools
%{_bindir}/%{name}-scanner

%files doc
%doc %{_docdir}/%{name}/*
%{_mandir}/man3/wl_*.3*


%changelog
* Thu Sep 21 2023 tv <tv> 1.22.0-1.mga10
+ Revision: 1989094
- Update to 1.22.0

* Thu Aug 11 2022 tmb <tmb> 1.21.0-1.mga9
+ Revision: 1877061
- update to 1.21.0

* Tue Mar 29 2022 tv <tv> 1.20.0-2.mga9
+ Revision: 1831854
- Close file descriptors not needed
- Run testsuite

* Thu Dec 16 2021 tv <tv> 1.20.0-1.mga9
+ Revision: 1762223
- Use meson to build
- 1.20.0

* Thu Aug 05 2021 luigiwalser <luigiwalser> 1.19.0-2.mga9
+ Revision: 1739671
- rebuild for libffi

* Mon May 03 2021 daviddavid <daviddavid> 1.19.0-1.mga9
+ Revision: 1721000
- new version: 1.19.0

* Tue Jun 16 2020 ovitters <ovitters> 1.18.0-3.mga8
+ Revision: 1593496
- rebuild for new ffi

* Sat Feb 15 2020 umeabot <umeabot> 1.18.0-2.mga8
+ Revision: 1523999
- Mageia 8 Mass Rebuild

* Wed Feb 12 2020 tv <tv> 1.mga8-current
+ Revision: 1509376
- 1.18.0
- new release
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Thu Mar 21 2019 tv <tv> 1.17.0-1.mga7
+ Revision: 1379482
- new release

* Sun Mar 17 2019 tv <tv> 1.16.93-1.mga7
+ Revision: 1378328
- 1.7 RC

* Sat Aug 25 2018 tv <tv> 1.16.0-1.mga7
+ Revision: 1253889
- new release

* Sun Aug 19 2018 tv <tv> 1.15.93-1.mga7
+ Revision: 1252778
- 1.16 RC2

* Tue Apr 17 2018 wally <wally> 1.15.0-4.mga7
+ Revision: 1219656
- one more devel pkg requires fix

* Tue Apr 17 2018 wally <wally> 1.15.0-3.mga7
+ Revision: 1219651
- fix devel pkg requires
+ tv <tv>
- submit to core/release as mesa 18 w/o libwayland-egl has been submitted there

* Tue Apr 10 2018 tv <tv> 1.15.0-1.mga7
+ Revision: 1216900
- new release

* Thu Apr 05 2018 tv <tv> 1.14.93-3.mga7
+ Revision: 1215368
- add epoch to libwayland-egl as wayland version is lower than mesa one
- submit to core/updates_testing where mesa droped libwayland-egl
- Update to 1.14.92
- Obsolete libwayland-egl from mesa

* Fri Dec 29 2017 luigiwalser <luigiwalser> 1.14.0-2.mga7
+ Revision: 1186883
- add patch from fedora to fix buffer overflow issue (mga#22241)

* Fri Aug 11 2017 tv <tv> 1.14.0-1.mga7
+ Revision: 1139612
- new release

* Wed Aug 02 2017 tv <tv> 1.13.92-1.mga7
+ Revision: 1133918
- new release

* Mon Jul 17 2017 tv <tv> 1.13.0-1.mga7
+ Revision: 1124351
- new release

* Wed Jun 01 2016 tv <tv> 1.11.0-1.mga6
+ Revision: 1019668
- 1.11.0

* Wed May 25 2016 tv <tv> 1.10.93-1.mga6
+ Revision: 1018247
- 1.11 RC1

* Wed May 18 2016 tv <tv> 1.10.91-1.mga6
+ Revision: 1016701
- new release
- new release

* Wed Feb 17 2016 tv <tv> 1.10.0-1.mga6
+ Revision: 963759
- 1.10.0
- 1.1.0

* Wed Jan 20 2016 ovitters <ovitters> 1.9.91-1.mga6
+ Revision: 926145
- new version 1.9.91

* Thu Sep 24 2015 tv <tv> 1.9.0-1.mga6
+ Revision: 883292
- new release

* Sat Sep 12 2015 blino <blino> 1.8.1-2.mga6
+ Revision: 878315
- enable back doc on arm/mips (publican has been replaced with xmlto upstream)

* Sun Jun 21 2015 ovitters <ovitters> 1.8.1-1.mga6
+ Revision: 838237
- new version 1.8.1

* Wed Oct 15 2014 umeabot <umeabot> 1.6.0-2.mga5
+ Revision: 750367
- Second Mageia 5 Mass Rebuild

* Fri Sep 19 2014 tv <tv> 1.6.0-1.mga5
+ Revision: 697370
- new release
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Fri Sep 12 2014 tv <tv> 1.5.93-1.mga5
+ Revision: 674830
- 1.6 RC2

* Sat Sep 06 2014 tv <tv> 1.5.92-1.mga5
+ Revision: 672535
- 1.6 RC1

* Tue Sep 02 2014 ovitters <ovitters> 1.5.91-1.mga5
+ Revision: 670889
- new version 1.5.91

* Fri Jun 06 2014 tv <tv> 1.5.0-1.mga5
+ Revision: 633898
- adjust file list
- new release

* Wed Feb 05 2014 neoclust <neoclust> 1.4.0-1.mga5
+ Revision: 583272
- New version 1.4.0

* Mon Oct 21 2013 umeabot <umeabot> 1.3.0-2.mga4
+ Revision: 541068
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 tv <tv> 1.3.0-1.mga4
+ Revision: 495051
- adjust file list
- new release

* Fri Aug 30 2013 tv <tv> 1.2.1-1.mga4
+ Revision: 473312
- new release

* Mon Jul 15 2013 tv <tv> 1.2.0-1.mga4
+ Revision: 454547
- new release

* Wed Jul 10 2013 fwang <fwang> 1.1.91-1.mga4
+ Revision: 452313
- update file list
- new version 1.1.91

* Mon Jun 10 2013 tv <tv> 1.1.0-1.mga4
+ Revision: 441436
- new release
- new release

* Mon Mar 11 2013 rtp <rtp> 1.0.3-4.mga3
+ Revision: 402103
- add missing BR on docbook xsl stylesheets.

* Mon Mar 11 2013 rtp <rtp> 1.0.3-3.mga3
+ Revision: 402087
- disable publican/doc on arm as publican will call fop which is in java.

* Mon Jan 14 2013 umeabot <umeabot> 1.0.3-2.mga3
+ Revision: 385647
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 19 2012 kamil <kamil> 1.0.3-1.mga3
+ Revision: 332737
- add publican as BR
- new version 1.0.3
- update Source0

* Tue Oct 23 2012 blino <blino> 1.0.0-1.mga3
+ Revision: 309354
- 1.0.0

* Wed Oct 17 2012 blino <blino> 0.99.0-1.mga3
+ Revision: 307401
- use Documentation group
- buildrequire doxygen
- add man pages in doc package
- 0.99.0 (this shoud really fix bi-arch install of devel with my wayland-scanner patches fixing i586 headers)

* Wed Oct 10 2012 blino <blino> 0.95.0-3.mga3
+ Revision: 304221
- move wayland-scanner in a new wayland-tools package to fix bi-arch install of devel packages

* Mon Aug 06 2012 luigiwalser <luigiwalser> 0.95.0-2.mga3
+ Revision: 278995
- rebuild for libffi

* Tue Jul 24 2012 blino <blino> 0.95.0-1.mga3
+ Revision: 274116
- 0.95.0

* Mon Jul 23 2012 blino <blino> 0.94.90-2.mga3
+ Revision: 273889
- require cursor lib in devel package

* Sun Jul 15 2012 blino <blino> 0.94.90-1.mga3
+ Revision: 271011
- buildrequires xsltproc for protocol doc
- 0.94.90 (add curso lib and doc packages)

* Wed Feb 29 2012 blino <blino> 0.85.0-4.mga2
+ Revision: 216084
- require client and server libraries in devel package

* Wed Feb 29 2012 blino <blino> 0.85.0-3.mga2
+ Revision: 216017
- move wayland-scanner and its aclocal files to the devel package

* Wed Feb 29 2012 dmorgan <dmorgan> 0.85.0-2.mga2
+ Revision: 216003
- Fix Requires in the devel package

* Wed Feb 29 2012 blino <blino> 0.85.0-1.mga2
+ Revision: 215965
- initial release
- Created package structure for wayland.

